@@ -6,6 +6,7 @@ import (
 	"github.com/go-test/deep"
 	"github.com/google/uuid"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 
 	"github.com/anchore/grype/grype/distro"
 	"github.com/anchore/grype/grype/pkg"
@@ -15,7 +16,8 @@ import (
 )
 
 func TestGetByDistro(t *testing.T) {
-	provider := NewVulnerabilityProvider(newMockStore())
+	provider, err := NewVulnerabilityProvider(newMockStore())
+	require.NoError(t, err)
 
 	d, err := distro.New(distro.Debian, "8", "")
 	if err != nil {
@@ -36,14 +38,14 @@ func TestGetByDistro(t *testing.T) {
 		{
 			Constraint: version.MustGetConstraint("< 2014.1.3-6", version.DebFormat),
 			ID:         "CVE-2014-fake-1",
-			Namespace:  "debian:8",
+			Namespace:  "debian:distro:debian:8",
 			CPEs:       []syftPkg.CPE{},
 			Advisories: []vulnerability.Advisory{},
 		},
 		{
 			Constraint: version.MustGetConstraint("< 2013.0.2-1", version.DebFormat),
 			ID:         "CVE-2013-fake-2",
-			Namespace:  "debian:8",
+			Namespace:  "debian:distro:debian:8",
 			CPEs:       []syftPkg.CPE{},
 			Advisories: []vulnerability.Advisory{},
 		},
@@ -59,7 +61,8 @@ func TestGetByDistro(t *testing.T) {
 }
 
 func TestGetByDistro_nilDistro(t *testing.T) {
-	provider := NewVulnerabilityProvider(newMockStore())
+	provider, err := NewVulnerabilityProvider(newMockStore())
+	require.NoError(t, err)
 
 	p := pkg.Package{
 		ID:   pkg.ID(uuid.NewString()),
@@ -97,12 +100,26 @@ func TestGetByCPE(t *testing.T) {
 					CPEs: []syftPkg.CPE{
 						must(syftPkg.NewCPE("cpe:2.3:*:activerecord:activerecord:*:*:something:*:*:ruby:*:*")),
 					},
-					Namespace:  "nvd",
+					Namespace:  "nvd:cpe",
+					Advisories: []vulnerability.Advisory{},
+				},
+			},
+		},
+		{
+			name: "match with normalization",
+			cpe:  must(syftPkg.NewCPE("cpe:2.3:*:ActiVERecord:ACTiveRecord:*:*:*:*:*:ruby:*:*")),
+			expected: []vulnerability.Vulnerability{
+				{
+					Constraint: version.MustGetConstraint("< 3.7.4", version.UnknownFormat),
+					ID:         "CVE-2014-fake-4",
+					CPEs: []syftPkg.CPE{
+						must(syftPkg.NewCPE("cpe:2.3:*:activerecord:activerecord:*:*:something:*:*:ruby:*:*")),
+					},
+					Namespace:  "nvd:cpe",
 					Advisories: []vulnerability.Advisory{},
 				},
 			},
 		},
-
 		{
 			name: "match from vendor & name",
 			cpe:  must(syftPkg.NewCPE("cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:*:*:*")),
@@ -113,7 +130,7 @@ func TestGetByCPE(t *testing.T) {
 					CPEs: []syftPkg.CPE{
 						must(syftPkg.NewCPE("cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:rails:*:*")),
 					},
-					Namespace:  "nvd",
+					Namespace:  "nvd:cpe",
 					Advisories: []vulnerability.Advisory{},
 				},
 				{
@@ -122,7 +139,7 @@ func TestGetByCPE(t *testing.T) {
 					CPEs: []syftPkg.CPE{
 						must(syftPkg.NewCPE("cpe:2.3:*:activerecord:activerecord:*:*:something:*:*:ruby:*:*")),
 					},
-					Namespace:  "nvd",
+					Namespace:  "nvd:cpe",
 					Advisories: []vulnerability.Advisory{},
 				},
 			},
@@ -138,7 +155,8 @@ func TestGetByCPE(t *testing.T) {
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
 
-			provider := NewVulnerabilityProvider(newMockStore())
+			provider, err := NewVulnerabilityProvider(newMockStore())
+			require.NoError(t, err)
 
 			actual, err := provider.GetByCPE(test.cpe)
 			if err != nil && !test.err {
