@@ -12,6 +12,7 @@ const (
 	DotnetMatcher      MatcherType = "dotnet-matcher"
 	JavascriptMatcher  MatcherType = "javascript-matcher"
 	MsrcMatcher        MatcherType = "msrc-matcher"
+	PortageMatcher     MatcherType = "portage-matcher"
 	GoModuleMatcher    MatcherType = "go-module-matcher"
 )
 
@@ -25,6 +26,7 @@ var AllMatcherTypes = []MatcherType{
 	DotnetMatcher,
 	JavascriptMatcher,
 	MsrcMatcher,
+	PortageMatcher,
 	GoModuleMatcher,
 }
 
