@@ -319,13 +319,23 @@ func TestNew(t *testing.T) {
 			},
 		},
 		{
-			name: "portage portage-metadata",
+			name: "portage-metadata",
 			syftPkg: syftPkg.Package{
 				MetadataType: syftPkg.PortageMetadataType,
 				Metadata: syftPkg.PortageMetadata{
-					Package:       "portage-testing",
-					Version:       "v0.0.1",
-					InstalledSize: 0,
+					Package:       "net-misc/curl",
+					Version:       "1.2.3",
+					InstalledSize: 1,
+				},
+			},
+		},
+		{
+			name: "hackage-metadata",
+			syftPkg: syftPkg.Package{
+				MetadataType: syftPkg.HackageMetadataType,
+				Metadata: syftPkg.HackageMetadata{
+					Name:    "hackage",
+					Version: "v0.0.1",
 				},
 			},
 		},
