@@ -7,7 +7,7 @@ import (
 	"github.com/CycloneDX/cyclonedx-go"
 	"github.com/stretchr/testify/assert"
 
-	v3 "github.com/anchore/grype/grype/db/v3"
+	grypeDb "github.com/anchore/grype/grype/db/v4"
 	"github.com/anchore/grype/grype/match"
 	"github.com/anchore/grype/grype/pkg"
 	"github.com/anchore/grype/grype/vulnerability"
@@ -158,7 +158,7 @@ func TestNewVulnerability_AddsFixedVersion(t *testing.T) {
 			match: match.Match{
 				Vulnerability: vulnerability.Vulnerability{
 					Fix: vulnerability.Fix{
-						State:    v3.NotFixedState,
+						State:    grypeDb.NotFixedState,
 						Versions: []string{},
 					},
 				},
@@ -173,7 +173,7 @@ func TestNewVulnerability_AddsFixedVersion(t *testing.T) {
 			match: match.Match{
 				Vulnerability: vulnerability.Vulnerability{
 					Fix: vulnerability.Fix{
-						State: v3.FixedState,
+						State: grypeDb.FixedState,
 						Versions: []string{
 							"v0.1.2",
 							"v1.3.7",
