@@ -304,6 +304,40 @@ func addDpkgMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Cata
 	})
 }
 
+func addPortageMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Catalog, theStore *mockStore, theResult *match.Matches) {
+	packages := catalog.PackagesByPath("/var/db/pkg/app-containers/skopeo-1.5.1/CONTENTS")
+	if len(packages) != 1 {
+		t.Logf("Portage Packages: %+v", packages)
+		t.Fatalf("problem with upstream syft cataloger (portage)")
+	}
+	thePkg := pkg.New(packages[0])
+	theVuln := theStore.backend["gentoo:distro:gentoo:2.8"][thePkg.Name][0]
+	vulnObj, err := vulnerability.NewVulnerability(theVuln)
+	if err != nil {
+		t.Fatalf("failed to create vuln obj: %+v", err)
+	}
+	theResult.Add(match.Match{
+		Vulnerability: *vulnObj,
+		Package:       thePkg,
+		Details: []match.Detail{
+			{
+				Type:       match.ExactDirectMatch,
+				Confidence: 1.0,
+				SearchedBy: map[string]interface{}{
+					"distro": map[string]string{
+						"type":    "gentoo",
+						"version": "portage",
+					},
+				},
+				Found: map[string]interface{}{
+					"constraint": "<= 1.6.0 (gentoo)",
+				},
+				Matcher: match.PortageMatcher,
+			},
+		},
+	})
+}
+
 func addRhelMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Catalog, theStore *mockStore, theResult *match.Matches) {
 	packages := catalog.PackagesByPath("/var/lib/rpm/Packages")
 	if len(packages) != 1 {
@@ -373,6 +407,40 @@ func addSlesMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Cata
 	})
 }
 
+func addHaskellMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Catalog, theStore *mockStore, theResult *match.Matches) {
+	packages := catalog.PackagesByPath("/haskell/stack.yaml")
+	if len(packages) < 1 {
+		t.Logf("Haskel Packages: %+v", packages)
+		t.Fatalf("problem with upstream syft cataloger (haskell)")
+	}
+	thePkg := pkg.New(packages[0])
+	theVuln := theStore.backend["github:language:haskell"][thePkg.Name][0]
+	vulnObj, err := vulnerability.NewVulnerability(theVuln)
+	if err != nil {
+		t.Fatalf("failed to create vuln obj: %+v", err)
+	}
+	theResult.Add(match.Match{
+		Vulnerability: *vulnObj,
+		Package:       thePkg,
+		Details: []match.Detail{
+			{
+				Type:       match.ExactDirectMatch,
+				Confidence: 1.0,
+				SearchedBy: map[string]interface{}{
+					"language": map[string]string{
+						"type":    "haskell",
+						"version": "",
+					},
+				},
+				Found: map[string]interface{}{
+					"constraint": "< 0.9.0 (haskell)",
+				},
+				Matcher: match.UnknownMatcherType,
+			},
+		},
+	})
+}
+
 func TestMatchByImage(t *testing.T) {
 	observedMatchers := internal.NewStringSet()
 	definedMatchers := internal.NewStringSet()
@@ -395,6 +463,7 @@ func TestMatchByImage(t *testing.T) {
 				addJavascriptMatches(t, theSource, catalog, theStore, &expectedMatches)
 				addDotnetMatches(t, theSource, catalog, theStore, &expectedMatches)
 				addGolangMatches(t, theSource, catalog, theStore, &expectedMatches)
+				addHaskellMatches(t, theSource, catalog, theStore, &expectedMatches)
 				return expectedMatches
 			},
 		},
@@ -422,6 +491,14 @@ func TestMatchByImage(t *testing.T) {
 				return expectedMatches
 			},
 		},
+		{
+			fixtureImage: "image-portage-match-coverage",
+			expectedFn: func(theSource source.Source, catalog *syftPkg.Catalog, theStore *mockStore) match.Matches {
+				expectedMatches := match.NewMatches()
+				addPortageMatches(t, theSource, catalog, theStore, &expectedMatches)
+				return expectedMatches
+			},
+		},
 	}
 
 	for _, test := range tests {
@@ -449,6 +526,9 @@ func TestMatchByImage(t *testing.T) {
 			config := cataloger.DefaultConfig()
 			config.Search.Scope = source.SquashedScope
 
+			// enable all catalogers to cover non default cases
+			config.Catalogers = []string{"all"}
+
 			theCatalog, _, theDistro, err := syft.CatalogPackages(theSource, config)
 			if err != nil {
 				t.Fatalf("could not get the source obj: %+v", err)
